<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="100px"
    >
      <el-form-item label="知识库标题" prop="emertitle">
        <el-input
          v-model="queryParams.emertitle"
          placeholder="请输入知识库标题"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="标题拼音码" prop="emerpym">
        <el-input
          v-model="queryParams.emerpym"
          placeholder="请输入知识库标题拼音码"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="启用标志" prop="qybz">
        <el-input
          v-model="queryParams.qybz"
          placeholder="请输入启用标志"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <!-- <el-form-item label="删除标志" prop="deleted">
        <el-input
          v-model="queryParams.deleted"
          placeholder="请输入删除标志"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item> -->
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
        type="primary"  
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:emer:add']"
          >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
        type="primary"
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:emer:edit']"
          >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
        type="primary"
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:emer:remove']"
          >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
        type="primary"
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['system:emer:export']"
          >导出
        </el-button>
      </el-col>
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table
      v-loading="loading"
      :data="emerList"
      @selection-change="handleSelectionChange"
      border
    > 
      <el-table-column type="selection" width="55" align="center" fixed="left" />
      <el-table-column label="序号" align="center" prop="newID" width="60px" fixed="left" />
      <!-- <el-table-column label="编号" align="center" prop="id" width="60px" /> -->
      <el-table-column
        label="知识库类型"
        align="center"
        prop="emertype"
        :show-overflow-tooltip="true"
        width="100px"
      />
      <el-table-column
        label="知识库标题"
        align="center"
        prop="emertitle"
        :show-overflow-tooltip="true"
        width="150px"
      />
      <el-table-column
        label="知识库内容"
        align="center"
        prop="emercontent"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="标题拼音码"
        align="center"
        prop="emerpym"
        :show-overflow-tooltip="true"
        width="120px"
      />
      <el-table-column
        label="启用标志"
        align="center"
        prop="qybz"
        :show-overflow-tooltip="true"
        width="80px"
      />
      <!-- <el-table-column
        label="删除标志"
        align="center"
        prop="deleted"
        :show-overflow-tooltip="true"
        width="80px"
      /> -->
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
        width="80px"
        fixed="right"
      >
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:emer:edit']"
            title="修改"
          >
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:emer:remove']"
            title="删除"
          >
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <div class="pag">
      <div class="pag1">
        <pagination
          v-show="total > 0"
          :total="total"
          :page.sync="queryParams.pageNum"
          :limit.sync="queryParams.pageSize"
          @pagination="getList"
        />
      </div>
    </div>

    <!-- 添加或修改知识库对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="900px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px" :inline="true">
        <el-form-item label="知识库类型" prop="emertype">
          <el-input v-model="form.emertype" placeholder="请输入知识库标题" style="width:210px" />
        </el-form-item>
        <el-form-item label="知识库标题" prop="emertitle">
          <el-input v-model="form.emertitle" placeholder="请输入知识库标题" style="width:210px" />
        </el-form-item>
         <el-form-item label="知识库拼音码" prop="emerpym">
          <el-input
            v-model="form.emerpym"
            placeholder="请输入知识库标题拼音码" style="width:210px"
          />
        </el-form-item>
        <el-form-item label="启用标志" prop="qybz">
          <el-input v-model="form.qybz" placeholder="请输入启用标志" style="width:210px" />
        </el-form-item>
        <el-form-item label="知识库内容:">
          <editor v-model="form.emercontent" :min-height="192" />
        </el-form-item>
       
        <!-- <el-form-item label="删除标志" prop="deleted">
          <el-input v-model="form.deleted" placeholder="请输入删除标志" />
        </el-form-item> -->
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listEmer,
  getEmer,
  delEmer,
  addEmer,
  updateEmer,
} from "@/api/system/emer";

export default {
  name: "Emer",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 知识库表格数据
      emerList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        emertype: null,
        emertitle: null,
        emercontent: null,
        emerpym: null,
        qybz: null,
        deleted: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        qybz: [
          {
            required: true,
            message: "启用标志不能为空",
            trigger: "blur",
          },
        ],
        deleted: [
          {
            required: true,
            message: "删除标志不能为空",
            trigger: "blur",
          },
        ],
      },
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询知识库列表 */
    getList() {
      this.loading = true;
      listEmer(this.queryParams).then((response) => {
        this.emerList = response.rows;
        response.rows.forEach((item, index) => 
        {item.newID =(this.queryParams.pageNum - 1) * this.queryParams.pageSize +index +1;
          });
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        emertype: null,
        emertitle: null,
        emercontent: null,
        emerpym: null,
        qybz: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        deleted: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "知识库信息维护";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids;
      getEmer(id).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "知识库信息维护";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id != null) {
            updateEmer(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addEmer(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除知识库信息编号为"' + ids + '"的数据项？').then(function() {
        return delEmer(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/emer/export', {
        ...this.queryParams
      }, `org_${new Date().getTime()}.xlsx`)
    }
  },
};
</script>
<style scoped>
.pag {
  width: 100%;
  display: flex;
  justify-content: center;
}
.pag1 {
  width: 30%;
}
.dialog-footer {
  display: flex;
  justify-content: center;
}
</style>
